@@ -272,7 +272,7 @@ def parse_cookie_file(cookie_file):
     cookies = {}
     with open(cookie_file, 'r') as fp:
         for line in fp:
-            if not re.match(r'^\#', line):
+            if not re.match(r'^#', line):
                 line_fields = line.strip().split('\t')
                 cookies[line_fields[5]] = line_fields[6]
     return cookies
